using FluentAssertions;
using Website.Markdig.Extensions.HtmlGenerators;
using Xunit;

namespace Website.Markdig.Extensions.Tests.HtmlGenerators {
	public class YouTubeEmbedHtmlGeneratorTests {
		[Theory]
		[InlineData("https://www.youtube.com/watch?v=0sVTZJo321s")]
		[InlineData("https://youtu.be/0sVTZJo321s")]
		public void GenerateHtml_WithLink_ReturnsHtml(string url) {
			var generator = new YouTubeEmbedHtmlGenerator();
			generator.GenerateHtml(url).Should().Be(@"<div class=""video-container""><iframe src=""https://www.youtube.com/embed/0sVTZJo321s"" title=""YouTube video player"" frameborder=""0"" allow=""accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"" allowfullscreen></iframe></div>");
		}
		
		[Theory]
		[InlineData("https://www.youtube.com/watch?v=0sVTZJo321s")]
		[InlineData("https://youtu.be/0sVTZJo321s")]
		public void IsMatch_WithMatchingLink_ReturnsTrue(string url) {
			var generator = new YouTubeEmbedHtmlGenerator();
			generator.IsMatch(url).Should().BeTrue();
		}

		[Theory]
		[InlineData("https://robware.uk/")]
		[InlineData("https://youtube.com/0sVTZJo321s")]
		public void IsMatch_WithNonMatchingLink_ReturnsFalse(string url) {
			var generator = new YouTubeEmbedHtmlGenerator();
			generator.IsMatch(url).Should().BeFalse();
		}
	}
}